#' A data-frame of best linear unbiased predicted (BLUE) phenotypes (4x)
"BLUEs.pheno"

#' A list of GIC estimates (4x)
"GIC_4x"

#' A list of identity-by-descent probabilities (4x)
"IBD_4x"

#' A list of phased maps (4x)
"phased_maplist.4x"

#' A list of recombination count data (4x)
"Rec_Data_4x"

#' A data-frame of phenotypes (4x)
"Phenotypes_4x"

#' A list of QTL results (4x)
"qtl_LODs.4x"

#' A list of all possible bi-allelic QTL segregation types (2x)
"segList_2x"

#' A list of all possible bi-allelic QTL segregation types (3x)
"segList_3x"

#' A list of all possible bi-allelic QTL segregation types (4x)
"segList_4x"

#' A list of all possible bi-allelic QTL segregation types (6x)
"segList_6x"

#' A matrix of SNP marker dosages (4x)
"SNP_dosages.4x"

#' Redundant genotype classes in quadrivalent transition matrix (4x)
"rem.quad"

#' Redundant genotype classes in hexavalent transition matrix (6x)
"rem.hex"

#' A list of hexaploid bivalent pairing configurations
"hexa.list"

#' A list of pairing predictions (4x)
"mr.ls"

#' Rcpp internal function Forward from forward-backward algorithm
"fx"

#' Rcpp internal function Backward from forward-backward algorithm
"bx"
